
/* Generated data (by glib-mkenums) */

#ifndef __CRIA_ENUMERATIONS_H__
#define __CRIA_ENUMERATIONS_H__

#include <glib-object.h>

#include "block.h"

G_BEGIN_DECLS
/* enumerations from "alignment.h" */

GType cria_alignment_get_type (void);
#define CRIA_TYPE_ALIGNMENT (cria_alignment_get_type())
GType cria_valignment_get_type (void);
#define CRIA_TYPE_VALIGNMENT (cria_valignment_get_type())
G_END_DECLS

#endif /* __CRIA_ENUMERATIONS_H__ */

/* Generated data ends here */

